@@ -25,37 +25,9 @@ use serde::{
     Deserialize, Deserializer, Serialize,
 };
 use serde_with::{serde_as, DurationMilliSeconds, DurationSeconds, TimestampSecondsWithFrac};
-use std::{error::Error, fmt, num::ParseIntError, str::FromStr};
+use std::str::FromStr;
 
-/// Represents a parsing error.
-#[derive(Debug, Clone)]
-pub struct ParseError(String);
-
-impl fmt::Display for ParseError {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "{}", self.0)
-    }
-}
-
-impl Error for ParseError {}
-
-impl From<serde_json::Error> for ParseError
-where
-    serde_json::Error: std::fmt::Debug,
-{
-    fn from(error: serde_json::Error) -> Self {
-        ParseError(format!("{:?}", error))
-    }
-}
-
-impl From<ParseIntError> for ParseError
-where
-    serde_json::Error: std::fmt::Debug,
-{
-    fn from(error: ParseIntError) -> Self {
-        ParseError(format!("{:?}", error))
-    }
-}
+use crate::ParseError;
 
 /// Describes the source of a message.
 #[derive(Serialize, Deserialize, Debug, PartialEq, Clone)]
@@ -314,7 +286,7 @@ pub struct Aircraft {
     /// This field is only returned for queries that specify an origin point, e.g.
     /// https://adsbexchange.com/api/aircraft/v2/lat/34.1/lon/-118.1/dist/10
     #[serde(rename = "dst", default)]
-    pub distance_nm: Option<f32>,
+    pub distance_nm: Option<f64>,
 
     pub emergency: Option<Emergency>,
 
@@ -336,12 +308,12 @@ pub struct Aircraft {
     pub gps_ok_before: Option<DateTime<Utc>>,
 
     #[serde(rename = "gs")]
-    pub ground_speed_knots: Option<f32>,
+    pub ground_speed_knots: Option<f64>,
 
     pub hex: String,
 
     #[serde(rename = "ias")]
-    pub indicated_air_speed_knots: Option<f32>,
+    pub indicated_air_speed_knots: Option<f64>,
 
     #[serde(rename = "alert", default, deserialize_with = "optional_bool_from_int")]
     pub is_alert: Option<bool>,
@@ -349,15 +321,15 @@ pub struct Aircraft {
     #[serde(rename = "lastPosition")]
     last_position: Option<AgedPosition>,
 
-    pub lat: Option<f32>,
+    pub lat: Option<f64>,
 
-    pub lon: Option<f32>,
+    pub lon: Option<f64>,
 
     #[serde(rename = "mach")]
-    pub mach: Option<f32>,
+    pub mach: Option<f64>,
 
     #[serde(rename = "mag_heading")]
-    pub magnetic_heading: Option<f32>,
+    pub magnetic_heading: Option<f64>,
 
     #[serde(rename = "type")]
     pub message_type: MessageType,
@@ -373,11 +345,11 @@ pub struct Aircraft {
 
     pub nav_altitude_mcp: Option<i32>,
 
-    pub nav_heading: Option<f32>,
+    pub nav_heading: Option<f64>,
 
     pub nav_modes: Option<Vec<NavMode>>,
 
-    pub nav_qnh: Option<f32>,
+    pub nav_qnh: Option<f64>,
 
     pub nic: Option<u8>,
 
@@ -395,13 +367,13 @@ pub struct Aircraft {
     #[serde(rename = "r")]
     pub registration: Option<String>,
 
-    pub roll: Option<f32>,
+    pub roll: Option<f64>,
 
-    pub rr_lat: Option<f32>,
+    pub rr_lat: Option<f64>,
 
-    pub rr_lon: Option<f32>,
+    pub rr_lon: Option<f64>,
 
-    pub rssi: f32,
+    pub rssi: f64,
 
     #[serde_as(as = "DurationSeconds<f64>")]
     pub seen: std::time::Duration,
@@ -428,14 +400,14 @@ pub struct Aircraft {
     #[serde(rename = "tat")]
     pub total_air_temperature: Option<i32>,
 
-    pub track: Option<f32>,
+    pub track: Option<f64>,
 
-    pub track_rate: Option<f32>,
+    pub track_rate: Option<f64>,
 
     #[serde(rename = "tas")]
-    pub true_air_speed_knots: Option<f32>,
+    pub true_air_speed_knots: Option<f64>,
 
-    pub true_heading: Option<f32>,
+    pub true_heading: Option<f64>,
 
     #[serde(rename = "wd")]
     pub wind_direction: Option<u16>,
